class Constants:
    THREAD_MESSAGE = ""
    PROXY_LIVE_URL = "https://clonebysun.com/api/tienich/checkliveproxy"
    PROXY_BASE_URL = "http://proxy.shoplike.vn/Api"
    GET_NEW_ENDPOINT = PROXY_BASE_URL + "/getNewProxy"
    GET_CURRENT_ENDPOINT = PROXY_BASE_URL + "/getCurrentProxy"

    PRODUCT_OVERVIEW = "productOverview_hoc_view_div"
    PRODUCT_SPECS = "productSpecifications-content"
    PRODUCT_SPECS_SCRIPT = "arguments[0].style.display = 'block';"
    PRODUCT_MICRO = ".a-normal.a-spacing-micro"

    MONITOR_WIDTH = 1920
    MONITOR_HEIGHT = 1080

    LOGGING_LEVELS = ["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]
